# VUXNX

This is a package for **a free AI in your console**.
## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install foobar.

```bash
pip install vuxnx
```

## Usage

```python
from consoleAI import ModelAI

# Initialize an instance for AI
model = ModelAI()

# Get response from model AI
response = model.prompt("How are you today?")
print(response)
```

## Contributing

Pull requests are welcome. For major changes, please open an issue first
to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License

[MIT](https://choosealicense.com/licenses/mit/)